@@ -133,8 +133,8 @@ class PupilsOAuth2Mixin(OAuth2Mixin):
     .. versionadded:: 3.2
     """
 
-    _OAUTH_ACCESS_TOKEN_URL = "http://127.0.0.1:9001/services/oauth/access_token?"
-    _OAUTH_AUTHORIZE_URL = "http://127.0.0.1:9001/services/oauth/ask?"
+    _OAUTH_ACCESS_TOKEN_URL = "http://www.gaotech.in/services/oauth/access_token?"
+    _OAUTH_AUTHORIZE_URL = "http://www.gaotech.in/services/oauth/ask?"
     _OAUTH_NO_CALLBACKS = False
     _OAUTH_SETTINGS_KEY = 'pupils_oauth'
 
@@ -168,7 +168,8 @@ class PupilsOAuth2Mixin(OAuth2Mixin):
             "code": code,
             "client_id": self.settings[self._OAUTH_SETTINGS_KEY]['key'],
             "client_secret": self.settings[self._OAUTH_SETTINGS_KEY]['secret'],
-            "grant_type": "authorization_code",
+            # "grant_type": "authorization_code",
+            "response_type": "token",
         })
 
         http.fetch(self._OAUTH_ACCESS_TOKEN_URL,
